% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% "%" is a comment tag, the rest of the line is discarded.
% #print can be sued to print a message or values of variables

#print "FP with thermal effect and ring heater"

% variables defined in this default sections can be overriden by the runtime option,
%		-par var = name
% variables can be redefined during the run, var = name and
% string expressions, like ITM.opt.HR_phase, use that new value when needed.

#defaults

% ring heater correction
RINV_ITM_RH = 0
RINV_ETM_RH = 0

#enddef

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Basic FFT setup
Nfft = 256        % number of grid points
Wfft = 0.70       % FFT window size, if not otherwise specified

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ITM and ETM specificaction
% mirror definition = [ aperture, thickness, mech, opt ]
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

aperture = 0.34
ITM.aperture = aperture
ETM.aperture = aperture

% mirror mechanical data = [ x, y, z, tX, tY, tZ ]
% definitions of the coordinate system is defined in the manual.
% [tX,tY,tZ] : pitch rotation = [0, -pitch,PI/2], yaw rotation = [0, yaw, 0]
ITM.mech = [ 0, 0, 0, 0, 0, 0 ]
ETM.mech = [ 0, 0, 0, 0, 0, 0 ]

%-------------------------------------------------------------------------------------
% mirror optoical data = [ T, R, ROC, refrIndex, "HR_phasemap", "trans_phasemap" ]
%
% THERMOELASTIC( beamSize, Psubs, Pcoat [, T0] ) for surface deformation
% THERMALPHASE( beamSize, Psubs, Pcoat [, T0] ) for thermal lens in substrate
%    values in ( ) below are typical values for advLIGO arm
%
%    beamSize : gaussian beam width on the mirror, 
%               if negative, the resonating field width is used
%    Psubs : power absorbed in substrate (0.084W),
%            if negative, it is used as an absorption rate ( (0.02ppm/cm) *100 m^-1)
%    Pcoat : power absorbed in coating (0.425W), 
%            if negative, it is an absorption rate (0.5E-6)
%-------------------------------------------------------------------------------------

ROC_ITM = 1971			% cold state ITM ROC
ROC_ETM = 2191			% cold state ETM ROC

T_ITM = 0.014			% ITM power transmittance
Pcav = 650e3			% typical advLIGO arm power
Pin = Pcav * T_ITM / 4	% calculate the input power for this FP
wITM = 0.055			% typical beam size on ITM
wETM = 0.062			% typical beam size on ETM

PsubsRate = 0.02e-6 * 100	% substrate abosrption
PcoatRate = 0.5e-6			% coating absorption

armLoss = 75e-6			% typical arm loss, modstly scattering loss, expected for advLIGO.

ITM.opt.T = T_ITM
ITM.opt.R = 1 - ITM.opt.T - armLoss/2
ITM.opt.ROC = ROC_ITM

% The thermal effect changes the surface figure
% A ring heater bents the mirror, so the figure changes like r^2 / 2 * (1/R)
% variables x, y, z, rr = x^2 + y^ and r = sqrt(rr) can be used on the right hand side
ITM.opt.HR_phase = THERMOELASTIC( -wITM, -PsubsRate, -PcoatRate ) + rr / 2 * RINV_ITM_RH
% and the transmission phase
ITM.opt.trans_phase = THERMALPHASE( -wITM, -PsubsRate, -PcoatRate )

ETM.opt.T = 5e-6
ETM.opt.R = 1 - ETM.opt.T - armLoss/2
ETM.opt.ROC = ROC_ETM
% ETM surface figure change by thermal deformation
ETM.opt.HR_phase = THERMOELASTIC( -wETM, 0, -PcoatRate ) + rr / 2 * RINV_ETM_RH

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Definition of the cavity
% cavity definition = 
%   [ L0, delL, matchToInput, Nfft, Ncut1, Ncut2, lockFP, adaptiveGrid ]
%
% L0 is macro length, rounted to integer multiple of NdYAG wave length
% delL is a microscopic correct 
% total length = lambda(NdYAG) * floor( L0 / lambda ) + delL
% set matchToInput to 1 or 3 to automatically set delL to mode match to the input beam

FPcav = [ 3995.420, 0, 3, 0, 0, 0, 1, 0 ]

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% input beam specification
% inputBeam definition = 
%   [ "BeamType", power, index1, index2, waistSize, waistPosition, matchToCavity ]
%
% input type = "LG" for LaguerreGuass( index1, index2 ) 
%              "HG" for HermiteGauss( index1, index2 )
%
% waist size and position are calculated when you use matchToCavity = 1. 
% You can setup the input mode by hand. 
% Then you need to set matchToCavity = 0 so that no automatic adjustment is done

inputBeam.beamType = "HG"
inputBeam.power = Pin
inputBeam.index1 = 0
inputBeam.index2 = 0
inputBeam.waistSize = 0
inputBeam.waistPosition = 0
inputBeam.matchToCavity = 1
